==> haskell-http-api-data-0.6.1-38.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.6.1
visibility:           public
id:                   http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
key:                  http-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  70cde02f7b6c1cd11bc81d6d26d4e57c
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.6.1-5XEHPNAfLnyD0ajpwpE9eT
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-iso8601-0.1.1-GF0rdlvxt50LplRlzOpaT9
    time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-types-1.0.6-58FfeLal0FhHrTZjsfHNqD

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.6.1-39-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.6.1
visibility:           public
id:                   http-api-data-0.6.1-6b8SlzeGz22trXyYobem
key:                  http-api-data-0.6.1-6b8SlzeGz22trXyYobem
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  90ff1451d2e1d18c375eca829072b05f
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-api-data-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.6.1-6b8SlzeGz22trXyYobem
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-iso8601-0.1.1-7s9wfG1NH3F6HcPkFbTT6y
    time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-types-1.0.6-21TzNsexUnW19QIZkyQGNe

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
